@@ -6,7 +6,7 @@ use warnings;
 
 use parent qw(Data::Clean::Base);
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -15,6 +15,12 @@ sub new {
     $class->SUPER::new(%opts);
 }
 
+sub get_cleanser {
+    my $class = shift;
+    state $singleton = $class->new;
+    $singleton;
+}
+
 1;
 # ABSTRACT: Clean data from JSON decoder
 
@@ -28,13 +34,13 @@ Data::Clean::FromJSON - Clean data from JSON decoder
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
  use Data::Clean::FromJSON;
  use JSON;
- my $cleanser = Data::Clean::FromJSON->new;
+ my $cleanser = Data::Clean::FromJSON->get_cleanser;
  my $data    = JSON->new->decode('[true]'); # -> [bless(do{\(my $o=1)},"JSON::XS::Boolean")]
  my $cleaned = $cleanser->clean_in_place($data); # -> [1]
 
@@ -45,7 +51,12 @@ This class can convert L<JSON::PP::Boolean> (or C<JSON::XS::Boolean>) objects to
 
 =head1 METHODS
 
-=head2 new(%opts) => $obj
+=head2 CLASS->get_cleanser => $obj
+
+Return a singleton instance, with default options. Use C<new()> if you want to
+customize options.
+
+=head2 CLASS->new(%opts) => $obj
 
 Create a new instance. For list of known options, see L<Data::Clean::Base>.
 Data::Clean::FromJSON sets some defaults.
@@ -61,6 +72,18 @@ Clean $data. Modify data in-place.
 
 Clean $data. Clone $data first.
 
+=head1 ENVIRONMENT
+
+LOG_CLEANSER_CODE
+
+=head1 FAQ
+
+=head2 Why am I getting 'Modification of a read-only value attempted at lib/Data/Clean/Base.pm line xxx'?
+
+[2013-10-15 ] This is also from Data::Clone::clone() when it encounters
+JSON::{PP,XS}::Boolean objects. You can use clean_in_place() instead of
+clone_and_clean(), or clone your data using other cloner like L<Storable>.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
