@@ -6,7 +6,7 @@ use warnings;
 
 use parent qw(Data::Clean::Base);
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -19,6 +19,12 @@ sub new {
     $class->SUPER::new(%opts);
 }
 
+sub get_cleanser {
+    my $class = shift;
+    state $singleton = $class->new;
+    $singleton;
+}
+
 1;
 # ABSTRACT: Clean data so it is safe to output to JSON
 
@@ -32,12 +38,12 @@ Data::Clean::JSON - Clean data so it is safe to output to JSON
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
  use Data::Clean::JSON;
- my $cleanser = Data::Clean::JSON->new;    # there are some options
+ my $cleanser = Data::Clean::JSON->get_cleanser;
  my $data     = { code=>sub {}, re=>qr/abc/i };
 
  my $cleaned;
@@ -65,19 +71,26 @@ The design goals are good performance, good defaults, and just enough
 flexibility. The original use-case is for returning JSON response in HTTP API
 service.
 
-This module is significantly faster than L<Data::Rmap> because with Rmap you
-repeatedly invoke anonymous subroutine for each data item. This module, on the
-other hand, generates a cleanser code using eval(), using native Perl for()
-loops.
+This module is significantly faster than modules like L<Data::Rmap> or
+L<Data::Visitor::Callback> because with something like Data::Rmap you repeatedly
+invoke callback for each data item. This module, on the other hand, generates a
+cleanser code using eval(), using native Perl for() loops.
 
-The generated cleanser code is logged using L<Log::Any> at trace level. You can
-see it, e.g. using L<Log::Any::App>:
+If C<LOG_CLEANSER_CODE> environment is set to true, the generated cleanser code
+will be logged using L<Log::Any> at trace level. You can see it, e.g. using
+L<Log::Any::App>:
 
- % TRACE=1 perl -MLog::Any::App -MData::Clean::JSON -e'$c=Data::Clean::JSON->new; ...'
+ % LOG_CLEANSER_CODE=1 TRACE=1 perl -MLog::Any::App -MData::Clean::JSON \
+   -e'$c=Data::Clean::JSON->new; ...'
 
 =head1 METHODS
 
-=head2 new(%opts) => $obj
+=head2 CLASS->get_cleanser => $obj
+
+Return a singleton instance, with default options. Use C<new()> if you want to
+customize options.
+
+=head2 CLASS->new(%opts) => $obj
 
 Create a new instance. For list of known options, see L<Data::Clean::Base>.
 Data::Clean::JSON sets some defaults.
@@ -97,6 +110,10 @@ Clean $data. Modify data in-place.
 
 Clean $data. Clone $data first.
 
+=head1 ENVIRONMENT
+
+LOG_CLEANSER_CODE
+
 =head1 FAQ
 
 =head2 Why clone/modify? Why not directly output JSON?
@@ -105,9 +122,10 @@ So that the data can be used for other stuffs, like outputting to YAML, etc.
 
 =head2 Why is it slow?
 
-First make sure that you do not construct the Data::Clean::JSON object
-repeatedly, as the constructor generates the cleanser code first using eval(). A
-short benchmark (run on my slow Atom netbook):
+If you use C<new()> instead of C<get_cleanser()>, make sure that you do not
+construct the Data::Clean::JSON object repeatedly, as the constructor generates
+the cleanser code first using eval(). A short benchmark (run on my slow Atom
+netbook):
 
  % bench -MData::Clean::JSON -b'$c=Data::Clean::JSON->new' \
      'Data::Clean::JSON->new->clone_and_clean([1..100])' \
@@ -144,6 +162,12 @@ an object. If you are cleaning objects, instead of using clone_and_clean(), try
 using clean_in_place(). Or, clone your data first using something else like
 L<Storable>.
 
+=head1 SEE ALSO
+
+L<Data::Rmap>
+
+L<Data::Visitor::Callback>
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
